{
  description = "my nixos setup";

  inputs = {
    nixpkgs.url = "github:nixos/nixpkgs/release-24.11";
    pkgsUnstable.url = "github:nixos/nixpkgs/nixpkgs-unstable";
    nixos-hardware.url = "github:NixOS/nixos-hardware/master";
    disko.url = "github:nix-community/disko/latest";
    disko.inputs.nixpkgs.follows = "nixpkgs";
  };

  outputs = { self, nixpkgs, disko, pkgsUnstable, nixos-hardware, ... }:
  let
    system = "x86_64-linux";
    lib = nixpkgs.lib;
    unstable = pkgsUnstable.legacyPackages.${system};
  in {

    nixosConfigurations = {
      vm = lib.nixosSystem {
        inherit system;
        specialArgs = { inherit unstable; };
        modules = [
          disko.nixosModules.disko
          ./system/vm/disk.nix
          ./system/vm/configuration.nix
        ];
      };
      chromebook = lib.nixosSystem {
        inherit system;
        specialArgs = { inherit unstable; };
        modules = [
          ./system/chromebook/configuration.nix
        ];
      };
      my-hp = lib.nixosSystem {
        inherit system;
        specialArgs = { inherit unstable; };
        modules = [
          ./system/my-hp/configuration.nix
        ];
      };
      old-hp = lib.nixosSystem {
        inherit system;
        specialArgs = { inherit unstable; };
        modules = [
          ./system/old-hp/configuration.nix
        ];
      };
      macmini12 = lib.nixosSystem {
        inherit system;
        specialArgs = { inherit unstable; };
        modules = [
          # add your model from this list: https://github.com/NixOS/nixos-hardware/blob/master/flake.nix
          nixos-hardware.nixosModules.apple-macmini-4-1
          ./system/macmini12/configuration.nix
        ];
      };
      macmini15 = lib.nixosSystem {
        inherit system;
        specialArgs = { inherit unstable; };
        modules = [
          # add your model from this list: https://github.com/NixOS/nixos-hardware/blob/master/flake.nix
          nixos-hardware.nixosModules.apple-macmini-4-1
          ./system/macmini15/configuration.nix
        ];
      };
      moms-hp = lib.nixosSystem {
        inherit system;
        specialArgs = { inherit unstable; };
        modules = [
          ./system/moms-hp/configuration.nix
        ];
      };
    };
  };
}
